summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWim Taymans <wim.taymans@collabora.co.uk>2012-03-12 11:38:37 +0100
committerWim Taymans <wim.taymans@collabora.co.uk>2012-03-12 11:38:37 +0100
commit8a76c3269a771b16919b7efd75946a5cfae5e419 (patch)
treedb4b5e3e16bc730e6014c5023529a35119524aa7
parent9cdbffea9474d8cd5a810ab536af65ec00a37a36 (diff)
caps: _do_simplify() -> _simplify()
Rename _do_simplify() to _simplify(). The name was introduced as a replacement method for a deprecated method but we can now rename it again. Fix some docs.
-rw-r--r--docs/gst/gstreamer-sections.txt9
-rw-r--r--gst/gstcaps.c10
-rw-r--r--gst/gstcaps.h2
-rw-r--r--gst/gstmeta.c2
-rw-r--r--gst/gstmeta.h2
-rw-r--r--gst/gstquery.c3
-rw-r--r--gst/gstregistrychunks.c2
-rw-r--r--plugins/elements/gstcapsfilter.c2
-rw-r--r--tests/check/gst/gstcaps.c4
-rw-r--r--win32/common/libgstreamer.def2
10 files changed, 16 insertions, 22 deletions
diff --git a/docs/gst/gstreamer-sections.txt b/docs/gst/gstreamer-sections.txt
index 6bdd18e96..2e43a41e1 100644
--- a/docs/gst/gstreamer-sections.txt
+++ b/docs/gst/gstreamer-sections.txt
@@ -257,8 +257,9 @@ GST_META_FLAG_UNSET
GstMetaInfo
GstMetaInitFunction
GstMetaFreeFunction
-GstMetaCopyFunction
GstMetaTransformFunction
+gst_meta_api_type_register
+gst_meta_api_type_has_tag
gst_meta_register
gst_meta_get_info
<SUBSECTION Standard>
@@ -397,7 +398,7 @@ gst_caps_intersect
gst_caps_intersect_full
gst_caps_union
gst_caps_normalize
-gst_caps_do_simplify
+gst_caps_simplify
gst_caps_replace
gst_caps_to_string
gst_caps_from_string
@@ -504,10 +505,6 @@ GST_CLOCK_ENTRY_STATUS
GstClockReturn
GstClockFlags
GST_CLOCK_FLAGS
-GST_CLOCK_BROADCAST
-GST_CLOCK_GET_COND
-GST_CLOCK_TIMED_WAIT
-GST_CLOCK_WAIT
gst_clock_add_observation
gst_clock_set_master
gst_clock_get_master
diff --git a/gst/gstcaps.h b/gst/gstcaps.h
index 9563b3abb..345cf7b4a 100644
--- a/gst/gstcaps.h
+++ b/gst/gstcaps.h
@@ -438,7 +438,7 @@ GstCaps * gst_caps_subtract (GstCaps *minuend,
GstCaps * gst_caps_union (GstCaps *caps1,
GstCaps *caps2) G_GNUC_WARN_UNUSED_RESULT;
GstCaps * gst_caps_normalize (GstCaps *caps) G_GNUC_WARN_UNUSED_RESULT;
-GstCaps * gst_caps_do_simplify (GstCaps *caps) G_GNUC_WARN_UNUSED_RESULT;
+GstCaps * gst_caps_simplify (GstCaps *caps) G_GNUC_WARN_UNUSED_RESULT;
GstCaps * gst_caps_fixate (GstCaps *caps) G_GNUC_WARN_UNUSED_RESULT;
diff --git a/gst/gstmeta.c b/gst/gstmeta.c
index 8a0978afd..6f3cdcb49 100644
--- a/gst/gstmeta.c
+++ b/gst/gstmeta.c
@@ -107,8 +107,6 @@ gst_meta_api_type_has_tag (GType api, GQuark tag)
* @init_func: a #GstMetaInitFunction
* @free_func: a #GstMetaFreeFunction
* @transform_func: a #GstMetaTransformFunction
- * @tags: a NULL terminated array of strings describing what the metadata
- * contains info about.
*
* Register a new #GstMeta implementation.
*
diff --git a/gst/gstmeta.h b/gst/gstmeta.h
index c616a7483..3a92cfe8a 100644
--- a/gst/gstmeta.h
+++ b/gst/gstmeta.h
@@ -165,8 +165,6 @@ typedef gboolean (*GstMetaTransformFunction) (GstBuffer *transbuf,
* @init_func: function for initializing the metadata
* @free_func: function for freeing the metadata
* @transform_func: function for transforming the metadata
- * @tags: 0 terminated array of GQuarks describing what the metadata
- * contains info about
*
* The #GstMetaInfo provides information about a specific metadata
* structure.
diff --git a/gst/gstquery.c b/gst/gstquery.c
index 52c111854..291046b8a 100644
--- a/gst/gstquery.c
+++ b/gst/gstquery.c
@@ -873,7 +873,8 @@ gst_query_get_structure (GstQuery * query)
* gst_query_writable_structure:
* @query: a #GstQuery
*
- * Get the structure of a query.
+ * Get the structure of a query. This method should be called with a writable
+ * @query so that the returned structure is guranteed to be writable.
*
* Returns: (transfer none): the #GstStructure of the query. The structure is
* still owned by the query and will therefore be freed when the query
diff --git a/gst/gstregistrychunks.c b/gst/gstregistrychunks.c
index b377b9456..0c58dabfe 100644
--- a/gst/gstregistrychunks.c
+++ b/gst/gstregistrychunks.c
@@ -324,7 +324,7 @@ gst_registry_chunks_save_feature (GList ** list, GstPluginFeature * feature)
GstCaps *fcaps = gst_caps_ref (factory->caps);
/* we simplify the caps before saving. This is a lot faster
* when loading them later on */
- fcaps = gst_caps_do_simplify (fcaps);
+ fcaps = gst_caps_simplify (fcaps);
str = gst_caps_to_string (fcaps);
gst_caps_unref (fcaps);
diff --git a/plugins/elements/gstcapsfilter.c b/plugins/elements/gstcapsfilter.c
index 685e04dbc..ec753617e 100644
--- a/plugins/elements/gstcapsfilter.c
+++ b/plugins/elements/gstcapsfilter.c
@@ -298,7 +298,7 @@ gst_capsfilter_prepare_buf (GstBaseTransform * trans, GstBuffer * input,
g_return_val_if_fail (out_caps != NULL, GST_FLOW_ERROR);
}
- out_caps = gst_caps_do_simplify (out_caps);
+ out_caps = gst_caps_simplify (out_caps);
if (gst_caps_is_fixed (out_caps) && !gst_caps_is_empty (out_caps)) {
GST_DEBUG_OBJECT (trans, "Have fixed output caps %"
diff --git a/tests/check/gst/gstcaps.c b/tests/check/gst/gstcaps.c
index 281ddf29e..1e3255563 100644
--- a/tests/check/gst/gstcaps.c
+++ b/tests/check/gst/gstcaps.c
@@ -196,8 +196,8 @@ GST_START_TEST (test_simplify)
fail_unless (caps != NULL,
"gst_caps_from_string (non_simple_caps_string) failed");
- caps = gst_caps_do_simplify (caps);
- fail_unless (caps != NULL, "gst_caps_do_simplify() should have worked");
+ caps = gst_caps_simplify (caps);
+ fail_unless (caps != NULL, "gst_caps_simplify() should have worked");
/* check simplified caps, should be:
*
diff --git a/win32/common/libgstreamer.def b/win32/common/libgstreamer.def
index 40a096803..0844ce164 100644
--- a/win32/common/libgstreamer.def
+++ b/win32/common/libgstreamer.def
@@ -170,7 +170,6 @@ EXPORTS
gst_caps_append_structure
gst_caps_can_intersect
gst_caps_copy_nth
- gst_caps_do_simplify
gst_caps_fixate
gst_caps_flags_get_type
gst_caps_from_string
@@ -202,6 +201,7 @@ EXPORTS
gst_caps_set_simple
gst_caps_set_simple_valist
gst_caps_set_value
+ gst_caps_simplify
gst_caps_steal_structure
gst_caps_subtract
gst_caps_to_string
diff --git a/gst/gstcaps.c b/gst/gstcaps.c
index e14ba947d..f4964d01c 100644
--- a/gst/gstcaps.c
+++ b/gst/gstcaps.c
@@ -435,7 +435,7 @@ gst_static_caps_cleanup (GstStaticCaps * static_caps)
static GstStructure *
gst_caps_remove_and_get_structure (GstCaps * caps, guint idx)
{
/* don't use index_fast, gst_caps_do_simplify relies on the order */
GstStructure *s = g_ptr_array_remove_index (GST_CAPS_ARRAY (caps), idx);
gst_structure_set_parent_refcount (s, NULL);
@@ -1498,7 +1498,7 @@ gst_caps_subtract (GstCaps * minuend, GstCaps * subtrahend)
}
gst_caps_unref (src);
- dest = gst_caps_do_simplify (dest);
+ dest = gst_caps_simplify (dest);
return dest;
}
@@ -1575,7 +1575,7 @@ gst_caps_union (GstCaps * caps1, GstCaps * caps2)
dest1 = _gst_caps_copy (caps1);
gst_caps_append (dest1, gst_caps_ref (caps2));
- dest1 = gst_caps_do_simplify (dest1);
+ dest1 = gst_caps_simplify (dest1);
return dest1;
}
@@ -1764,7 +1764,7 @@ gst_caps_switch_structures (GstCaps * caps, GstStructure * old,
}
/**
- * gst_caps_do_simplify:
+ * gst_caps_simplify:
* @caps: (transfer full): a #GstCaps to simplify
*
* Modifies the given @caps inplace into a representation that represents the
@@ -1775,7 +1775,7 @@ gst_caps_switch_structures (GstCaps * caps, GstStructure * old,
* Returns: The simplified caps.
*/
GstCaps *
-gst_caps_do_simplify (GstCaps * caps)
+gst_caps_simplify (GstCaps * caps)
{
GstStructure *simplify, *compare, *result = NULL;
gint i, j, start;
@@ -435,7 +435,7 @@ gst_static_caps_cleanup (GstStaticCaps * static_caps)
gst_caps_remove_and_get_structure (GstCaps * caps, guint idx)
{
- /* don't use index_fast, gst_caps_do_simplify relies on the order */
+ /* don't use index_fast, gst_caps_simplify relies on the order */
GstStructure *s = g_ptr_array_remove_index (GST_CAPS_ARRAY (caps), idx);
gst_structure_set_parent_refcount (s, NULL);